@@ -1,6 +1,6 @@
 package OpenGuides::SuperSearch;
 use strict;
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use CGI qw( :standard );
 use CGI::Wiki::Plugin::Locator::Grid;
@@ -155,6 +155,8 @@ sub run {
         $doing_search = 1;
         # Make sure to pass the criteria to the template.
         $tt_vars{dist} = $self->{distance_in_metres};
+        $tt_vars{latitude} = $self->{latitude};
+        $tt_vars{longitude} = $self->{longitude};
         if ( $self->config->geo_handler eq 1 ) {
             $tt_vars{coord_field_1_value} = $self->{os_x};
             $tt_vars{coord_field_2_value} = $self->{os_y};
@@ -252,6 +254,11 @@ sub run {
     my $formatter = $self->wiki->formatter;
     foreach my $i ( 0 .. $#results ) {
         my $name = $results[$i]{name};
+
+        # Add the one-line summary of the node, if there is one.
+        my %node = $self->wiki->retrieve_node($name);
+        $results[$i]{summary} = $node{metadata}{summary}[0];
+
         my $node_param = $formatter->node_name_to_node_param( $name );
         $results[$i]{url} = $self->{wikimain} . "?$node_param";
     }
